@@ -230,7 +230,11 @@ setClass("NCLists",
     )
 )
 
-setMethod("parallelSlotNames", "NCLists",
+### Combine the new "vertical slots" with those of the parent class. Make
+### sure to put the new vertical slots **first**. See R/bindROWS.R file in
+### the S4Vectors package for what slots should or should not be considered
+### "vertical".
+setMethod("vertical_slot_names", "NCLists",
     function(x) c("nclists", "rglist", callNextMethod())
 )
 
