@@ -26,17 +26,13 @@ setClass("RangedData", contains = c("DataTable", "List"),
          prototype = prototype(ranges = new("SimpleIRangesList"),
                                values = new("CompressedSplitDataFrameList")))
 
-wmsg2 <- function(...)
-    paste0("  ",
-           paste0(strwrap(paste0(c(...), collapse="")), collapse="\n  "))
-
-RangedData_is_deprecated_msg <-
-  c("RangedData objects are deprecated. ",
+.RangedData_is_defunct_msg <-
+  c("RangedData objects are defunct. ",
     "Please migrate your code to use GRanges or GRangesList objects instead. ",
     "See IMPORTANT NOTE in ?RangedData")
 
 RangedData_method_is_defunct_msg <- function(what)
-  c("RangedData objects are deprecated and the ", what, " is now defunct. ",
+  c("RangedData objects are defunct and so is the ", what, ". ",
     "Please migrate your code to use GRanges or GRangesList objects instead. ",
     "See IMPORTANT NOTE in ?RangedData")
 
@@ -46,13 +42,15 @@ RangedData_method_is_defunct_msg <- function(what)
 
 setMethod("values", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "values() getter for there objects"
+        .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         x@values
     })
 
 setReplaceMethod("values", "RangedData",
                  function(x, value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "values() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    if (extends(class(value), "SplitDataFrameList")) {
                      if (!identical(elementNROWS(values(x)),
                                     elementNROWS(value)))
@@ -78,7 +76,8 @@ setMethod("ranges", "RangedData",
 
 setReplaceMethod("ranges", "RangedData",
                  function(x, value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "ranges() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    if (extends(class(value), "IntegerRangesList")) {
                      if (!identical(lapply(ranges(x), names), lapply(value, names)))
                        stop("'value' must have same length and names as current 'ranges'")
@@ -94,81 +93,92 @@ setReplaceMethod("ranges", "RangedData",
 ## range delegates
 setMethod("start", "RangedData",
           function(x) {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "start() getter for these objects"
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             start(unlist(ranges(x), use.names=FALSE))
           })
 setMethod("end", "RangedData",
           function(x) {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "end() getter for these objects"
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             end(unlist(ranges(x), use.names=FALSE))
           })
 setMethod("width", "RangedData",
           function(x) {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "width() getter for these objects"
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             width(unlist(ranges(x), use.names=FALSE))
           })
 setReplaceMethod("start", "RangedData",
                  function(x, ..., value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "start() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    start(ranges(x), ...) <- value
                    x
                  })
 setReplaceMethod("end", "RangedData",
                  function(x, ..., value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "end() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    end(ranges(x), ...) <- value
                    x
                  })
 setReplaceMethod("width", "RangedData",
                  function(x, ..., value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "width() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    width(ranges(x), ...) <- value
                    x
                  })
 setMethod("length", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "length() method for these objects"
+        .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         length(ranges(x))
     })
 setMethod("names", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "names() getter for these objects"
+        .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         names(ranges(x))
     })
 setReplaceMethod("names", "RangedData",
                  function(x, value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "names() setter for these objects"
+                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    if (!is.null(value) && !is.character(value))
                      stop("'value' must be NULL or a character vector")
                    names(x@ranges) <- value
                    names(x@values) <- value
                    x
                  })
-### Used in [ and indirectly in .show_RangedData() (via [) so making this
-### Defunct breaks [ and show(RangedData).
 setMethod("elementNROWS", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "elementNROWS() method for these objects"
+        .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         elementNROWS(ranges(x))
     })
 
 setMethod("space", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "space() getter for these objects"
+        Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         space(ranges(x))
     })
 
 setGeneric("universe", function(x) standardGeneric("universe"))
 setMethod("universe", "RangedData",
     function(x) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+        what <- "universe() getter for these objects"
+        Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
         universe(ranges(x))
     })
 
 setGeneric("universe<-", function(x, value) standardGeneric("universe<-"))
 setReplaceMethod("universe", "RangedData",
                  function(x, value) {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "universe() setter for these objects"
+                   Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    universe(x@ranges) <- value
                    x
                  })
@@ -176,17 +186,20 @@ setReplaceMethod("universe", "RangedData",
 ## values delegates
 setMethod("nrow", "RangedData",
           function(x) {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "nrow() getter for these objects"
+            Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             sum(nrow(values(x)))
           })
 setMethod("ncol", "RangedData",
           function(x) {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "ncol() getter for these objects"
+            Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             ncol(values(x))[[1L]]
           })
 setMethod("rownames", "RangedData",
           function(x, do.NULL = TRUE, prefix = "row") {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "rownames() getter for these objects"
+            Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             rn <-
               unlist(rownames(values(x), do.NULL = do.NULL, prefix = prefix),
                      use.names=FALSE)
@@ -196,57 +209,13 @@ setMethod("rownames", "RangedData",
           })
 setMethod("colnames", "RangedData",
           function(x, do.NULL = TRUE, prefix = "col") {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "colnames() getter for these objects"
+            Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             if (length(x) == 0)
               character()
             else
               colnames(values(x), do.NULL = do.NULL, prefix = prefix)[[1L]]
           })
-setReplaceMethod("rownames", "RangedData",
-                 function(x, value) {
-                   what <- "rownames setter for RangedData objects"
-                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-                   if (!is.null(value)) {
-                     if (length(value) != nrow(x)) {
-                       stop("invalid 'row.names' length")
-                     } else {
-                       if (!is.character(value))
-                         value <- as.character(value)
-                       ends <- cumsum(elementNROWS(x))
-                       value <-
-                         new("CompressedCharacterList",
-                             unlistData = value,
-                             partitioning = PartitioningByEnd(ends))
-                     }
-                   }
-                   ranges <- ranges(x)
-                   for(i in seq_len(length(ranges))) {
-                     names(ranges[[i]]) <- value[[i]]
-                   }
-                   x@ranges <- ranges
-                   rownames(x@values) <- value
-                   x
-                 })
-setReplaceMethod("colnames", "RangedData",
-                 function(x, value) {
-                   what <- "colnames setter for RangedData objects"
-                   .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-                   colnames(x@values) <- value
-                   x
-                 })
-
-setMethod("columnMetadata", "RangedData", function(x) {
-  what <- "columnMetadata getter for RangedData objects"
-  .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-  columnMetadata(values(x))
-})
-
-setReplaceMethod("columnMetadata", "RangedData", function(x, value) {
-  what <- "columnMetadata setter for RangedData objects"
-  .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-  columnMetadata(values(x)) <- value
-  x
-})
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Validity.
@@ -272,7 +241,7 @@ setReplaceMethod("columnMetadata", "RangedData", function(x, value) {
 }
 
 .valid.RangedData <- function(x) {
-  .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+  .Defunct(msg=wmsg(.RangedData_is_defunct_msg))
   c(.valid.RangedData.ranges(x), .valid.RangedData.names(x))
 }
 
@@ -286,7 +255,7 @@ setValidity2("RangedData", .valid.RangedData)
 
 RangedData <- function(ranges = IRanges(), ..., space = NULL)
 {
-  .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+  .Defunct(msg=wmsg(.RangedData_is_defunct_msg))
   hasDots <- (((nargs() - !missing(space))) > 1)
   if (is(ranges, "IntegerRangesList") && !is(ranges, "IntegerRanges")) {
     if (!is.null(space))
@@ -367,7 +336,8 @@ RangedData <- function(ranges = IRanges(), ..., space = NULL)
 setMethod("[[", "RangedData",
           function(x, i, j, ...)
           {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "[[ method for these objects"
+            Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             dotArgs <- list(...)
             if (length(dotArgs) > 0)
                 dotArgs <- dotArgs[names(dotArgs) != "exact"]
@@ -397,7 +367,8 @@ setMethod("[[", "RangedData",
 setReplaceMethod("[[", "RangedData",
                  function(x, i, j,..., value)
                  {
-                   .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+                   what <- "[[<- method for these objects"
+                   Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
                    if (!missing(j) || length(list(...)) > 0)
                      stop("invalid subsetting")
                    if (missing(i))
@@ -442,7 +413,8 @@ setReplaceMethod("[[", "RangedData",
 setMethod("[", "RangedData",
           function(x, i, j, ..., drop=FALSE)
           {
-            .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+            what <- "[ method for these objects"
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             if (length(list(...)) > 0)
               stop("parameters in '...' not supported")
             if (missing(i) && missing(j))
@@ -555,60 +527,6 @@ setMethod("[", "RangedData",
             x
           })
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Combining and splitting.
-###
-
-setMethod("c", "RangedData", function(x, ..., recursive = FALSE) {
-  what <- "c() method for RangedData objects"
-  .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-  if (!identical(recursive, FALSE))
-    stop("\"c\" method for RangedData objects ",
-         "does not support the 'recursive' argument")
-  if (missing(x))
-    rds <- unname(list(...))
-  else
-    rds <- unname(list(x, ...))
-  rd <- rds[[1L]]
-  if (!all(sapply(rds, is, "RangedData")))
-    stop("all arguments in '...' must be RangedData objects")
-  nms <- lapply(rds, ## figure out names like 'c' on an ordinary vector
-                function(rd) structure(logical(length(rd)), names = names(rd)))
-  nms <- names(do.call(c, nms))
-  names(rds) <- NULL # critical for dispatch to work
-  ranges <- do.call(c, lapply(rds, ranges))
-  values <- do.call(c, lapply(rds, values))
-  names(ranges) <- nms
-  rd@ranges <- ranges
-  names(values) <- nms
-  rd@values <- values
-  rd
-})
-
-setMethod("rbind", "RangedData", function(..., deparse.level=1) {
-  what <- "rbind() method for RangedData objects"
-  .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-  args <- unname(list(...))
-  rls <- lapply(args, ranges)
-  nms <- unique(unlist(lapply(args, names), use.names=FALSE))
-  rls <- lapply(rls, function(x) {y <- as.list(x)[nms];names(y) <- nms;y})
-  dfs <-
-    lapply(args, function(x) {y <- as.list(values(x))[nms];names(y) <- nms;y})
-  safe.c <- function(...) {
-    x <- list(...)
-    do.call(c, x[!sapply(x, is.null)])
-  }
-  rls <- IRangesList(do.call(Map, c(list(safe.c), rls)))
-  safe.rbind <- function(...) {
-    x <- list(...)
-    do.call(rbind, x[!sapply(x, is.null)])
-  }
-  dfs <- SplitDataFrameList(do.call(Map, c(list(safe.rbind), dfs)))
-  for (i in seq_len(length(rls)))
-    names(rls[[i]]) <- rownames(dfs[[i]])
-  initialize(args[[1L]], ranges = rls, values = dfs)
-})
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Coercion
 ###
@@ -657,33 +575,10 @@ setMethod("rbind", "RangedData", function(..., deparse.level=1) {
     as.data.frame(stacked, row.names = row.names, optional = optional)
 }
 
-.as.data.frame.RangedData <- function(x, row.names=NULL, optional=FALSE, ...)
-{
-    what <- "as.data.frame() method for RangedData objects"
-    .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-    if (!(is.null(row.names) || is.character(row.names)))
-        stop("'row.names'  must be NULL or a character vector")
-    if (!missing(optional) || length(list(...)))
-        warning("'optional' and arguments in '...' ignored")
-    data.frame(.as.data.frame.IntegerRangesList(ranges(x)),
-               .as.data.frame.DataFrameList(values(x))[-1L],
-               row.names = row.names,
-               stringsAsFactors = FALSE)
-}
-setMethod("as.data.frame", "RangedData", .as.data.frame.RangedData)
-
-setAs("RangedData", "DFrame",
-      function(from)
-      {
-        what <- "coercion method from RangedData to DFrame"
-        .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-        DataFrame(as.data.frame(ranges(from)),
-                  unlist(values(from), use.names=FALSE))
-      })
-
 .fromRangedDataToCompressedIRangesList <- function(from)
 {
-    .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+    what <- "coercion from RangedData to IRangesList"
+    .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
     ans <- ranges(from)
     ## Propagate 'values(from)'.
     ans_unlisted_values <- unlist(values(from), use.names=FALSE)
@@ -696,27 +591,6 @@ setAs("RangedData", "CompressedIRangesList",
 )
 setAs("RangedData", "IRangesList", .fromRangedDataToCompressedIRangesList)
 
-setMethod("as.env", "RangedData", function(x, enclos = parent.frame(2)) {
-  what <- "as.env() method for RangedData objects"
-  .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
-  env <- S4Vectors:::makeEnvForNames(x, colnames(x), enclos)
-  makeAccessorBinding <- function(fun, name = deparse(substitute(fun))) {
-    makeActiveBinding(name, function() {
-      val <- fun(x)
-      rm(list=name, envir=env)
-      assign(name, val, env) ## cache for further use
-      val
-    }, env)
-  }
-  makeAccessorBinding(ranges)
-  makeAccessorBinding(space)
-  makeAccessorBinding(start)
-  makeAccessorBinding(width)
-  makeAccessorBinding(end)
-  env
-})
-
-
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Show
 ###
@@ -796,7 +670,7 @@ setMethod("as.env", "RangedData", function(x, enclos = parent.frame(2)) {
 
 setMethod("show", "RangedData",
     function(object) {
-        .Deprecated(msg=wmsg2(RangedData_is_deprecated_msg))
+         .Defunct(msg=wmsg(.RangedData_is_defunct_msg))
          suppressWarnings(.show_RangedData(object))
     })
 
